@@ -27,19 +27,11 @@ from parse.parser import *
 from io.output import *
 from gen.structure import *
 from gen.container import *
-from gen.inset import *
 
 
 class Layout(Container):
   "A layout (block of text) inside a lyx file"
 
-  typetags = {
-      'Quote':'blockquote', 'Standard':'div', 'Part':'h1',
-      'Chapter':'h1', 'Section':'h2', 'Subsection':'h3', 'Subsubsection':'h4',
-      'Quotation':'blockquote', 'Center':'div', 'Paragraph':'div',
-      'LyX-Code':'pre'
-      }
-
   def __init__(self):
     self.contents = list()
     self.parser = BoundedParser()
@@ -47,16 +39,23 @@ class Layout(Container):
 
   def process(self):
     self.type = self.header[1]
-    if self.type in Layout.typetags:
-      self.output.tag = Layout.typetags[self.type] + ' class="' + self.type + '"'
-    elif self.type.replace('*', '') in Layout.typetags:
-      self.output.tag = Layout.typetags[self.type.replace('*', '')] + ' class="' +  self.type.replace('*', '-') + '"'
+    if self.type in TagConfig.layouts:
+      self.output.tag = TagConfig.layouts[self.type] + ' class="' + self.type + '"'
+    elif self.type.replace('*', '') in TagConfig.layouts:
+      self.output.tag = TagConfig.layouts[self.type.replace('*', '')] + ' class="' +  self.type.replace('*', '-') + '"'
     else:
       self.output.tag = 'div class="' + self.type + '"'
 
   def __str__(self):
     return 'Layout of type ' + self.type
 
+class StandardLayout(Layout):
+  "A standard layout -- can be a true div or a span"
+
+  def process(self):
+    self.type = 'standard'
+    self.output.tag = 'span class="Standard"'
+
 class Title(Layout):
   "The title of the whole document"
 
