@@ -69,7 +69,7 @@ class Newline(Container):
 
   def process(self):
     "Process contents"
-    self.html = '<br/>'
+    self.html = ['<br/>']
 
 class Appendix(Container):
   "An appendix to the main document"
@@ -87,8 +87,6 @@ class ListItem(Container):
     self.parser = BoundedParser()
     self.output = EmptyOutput()
 
-  typetags = {'Enumerate':'ol', 'Itemize':'ul'}
-
   def process(self):
     "Set the correct type and contents."
     self.type = self.header[1]
@@ -117,3 +115,10 @@ class DeeperList(Container):
       result += str(element) + ', '
     return result[:-2] + ']'
 
+class ERT(Container):
+  "Evil Red Text"
+
+  def __init__(self):
+    self.parser = InsetParser()
+    self.output = EmptyOutput()
+
