@@ -30,6 +30,9 @@ from post.postprocess import *
 class PostFormula(object):
   "Postprocess a formula"
 
+  def __init__(self):
+    self.generator = NumberGenerator()
+
   def postprocess(self, current, last):
     "Postprocess any formulae"
     for formula in current.searchall(Formula):
@@ -41,6 +44,7 @@ class PostFormula(object):
     for index, bit in enumerate(contents):
       self.checklimited(contents, index)
       self.checkroot(contents, index)
+      self.checknumber(contents, index)
       if isinstance(bit, FormulaBit):
         self.postcontents(bit.contents)
 
@@ -89,5 +93,24 @@ class PostFormula(object):
     root = TaggedText().complete(bit.contents, 'span class="root"')
     bit.contents = [radical, root]
 
+  def checknumber(self, contents, index):
+    "Check for equation numbering"
+    label = contents[index]
+    if not isinstance(label, LabelFunction):
+      return
+    if len(label.contents) != 1:
+      Trace.error('Wrong contents for label ' + str(label))
+      return
+    bracket = label.contents[0]
+    labelname = bracket.contents
+    number = '(' + self.generator.generate(1) + ') '
+    Label.names[labelname] = label
+    tag = label.output.tag.replace('#', labelname)
+    label.output.settag(tag)
+    label.contents = [FormulaConstant(number)]
+    # place number at the beginning
+    del contents[index]
+    contents.insert(0, label)
+
 Postprocessor.unconditional.append(PostFormula)
 
